#!/usr/bin/env python3
# -*- encoding: utf-8; py-indent-offset: 4 -*-
# (c) Louis Wevers - <gluster-checkmk@wevers.tv> 2022

# This is free software;  you can redistribute it and/or modify it
# under the  terms of the  GNU General Public License  as published by
# the Free Software Foundation in version 2.  check_mk is  distributed
# in the hope that it will be useful, but WITHOUT ANY WARRANTY;  with-
# out even the implied warranty of  MERCHANTABILITY  or  FITNESS FOR A
# PARTICULAR PURPOSE. See the  GNU General Public License for more de-
# ails.  You should have  received  a copy of the  GNU  General Public
# License along with GNU Make; see the file  COPYING.  If  not,  write
# to the Free Software Foundation, Inc., 51 Franklin St,  Fifth Floor,
# Boston, MA 02110-1301 USA.

# Example for output from agent
# ---------------------------------------------------------
# <<<gluster>>>
# peer host-1 Connected
# peer host-2 Disconnected
# peer host-3 Connected
# volume Volume-1 0
# volume Volume-2 0
# volume Volume-3 0
# volume Volume-4 1
# volume Volume-5 0
# quota Volume-1_/ 10.0GB,80%(8.0GB),8.6GB,1.4GB,Yes,No
# quota Volume-2_/ 10.0GB,80%(8.0GB),8.6GB,1.4GB,No,No
# quota Volume-2_/test 2.0GB,80%(1.6GB),875.8MB,1.1GB,No,No


from .agent_based_api.v1 import *

def discovery_gluster(section):
    for servicetype, name, _state in section:
        service=servicetype + " " + name
        yield Service(item=service)

def check_gluster(item, section):
    for servicetype, name, state in section:
        service=servicetype + " " + name
        if service == item:
            if servicetype == "peer":
                if state == "Connected":
                    s = State.OK
                    desc = "Gluster daemon running"
                elif state == "Disconnected":
                    s = State.CRIT
                    desc = "Glusterdaemon not running"
                elif state == "glusterd":
                    s = State.CRIT
                    desc = "Glusterdaemon not running"
                elif state == "glusterfsd":
                    s = State.CRIT
                    desc = "Gluster brick daemon not running"
                yield Result (state = s, summary = f"{desc}")
            elif servicetype == "volume":
                state = int(state)
                if state > 0:
                    s = State.CRIT
                else:
                    s = State.OK
                yield Result (state = s, summary = f"{state} file(s) need healing")
            elif servicetype == "quota":
                states = state.split(",")
                if states[5] == "Yes":
                    s = State.CRIT
                elif states[4] == "Yes":
                    s = State.WARN
                else:
                    s = State.OK
                yield Result (state = s, summary = f"Used {states[2]} of {states[0]}. {states[3]} available")
    return

    yield Result (state = State.OK)

register.check_plugin(
    name="gluster",
    service_name="Gluster %s",
    discovery_function=discovery_gluster,
    check_function=check_gluster,
    )
